@@ -25,7 +25,7 @@ use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $AUTOLOAD);
 require Exporter;
 require DynaLoader;
 
-our $VERSION='0.75_02';
+our $VERSION='0.75_03';
 
 @ISA = qw(Exporter DynaLoader);
 %EXPORT_TAGS = (nodetypes => [qw(BTAST_STRING BTAST_MACRO BTAST_NUMBER)],
@@ -49,14 +49,21 @@ our $VERSION='0.75_02';
               'check_class', 'display_list' );
 @EXPORT = @{$EXPORT_TAGS{'metatypes'}};
 
-use Encode;
+use Encode 'encode', 'decode';
 use Unicode::Normalize;
 
 sub _process_result {
-    my ( $self, $result, $encoding ) = @_;
+  no strict 'refs';
+  my ( $self, $result, $encoding, $norm ) = @_;
 
+  my $normsub = \&{"$norm"}; # symbolic ref
     if ( $encoding eq "utf-8" ) {
-        return NFC( decode( $encoding, $result ) );
+        if ( utf8::is_utf8($result) ) {
+            return $normsub->($result);
+        }
+        else {
+            return $normsub->( decode( $encoding, $result ) );
+        }
     }
     else { return $result; }
 
@@ -65,14 +72,24 @@ sub _process_result {
 sub _process_argument {
     my ( $self, $value, $encoding ) = @_;
 
-    if ( $encoding eq "utf-8" ) {
-        return encode( $encoding, $value );
-    }
-    else {
+     if ( $encoding eq "utf-8" && utf8::is_utf8($value)) {
+         return encode( $encoding, $value );
+     }
+     else {
         return $value;
     }
 }
 
+sub split_list {
+    my ( $field, $delim, $filename, $line, $desc, $opts ) = @_;
+    $opts //= {};
+    $opts->{binmode} ||= 'bytes';
+    $opts->{normalization} ||= 'NFC';
+    return
+        map { Text::BibTeX->_process_result( $_, $opts->{binmode}, $opts->{normalization} ) }
+        Text::BibTeX::isplit_list( $field, $delim, $filename, $line, $desc );
+
+}
 
 =head1 NAME
 
@@ -598,7 +615,7 @@ of it as appropriate.  They're just mentioned here for completeness.
 
 =over 4
 
-=item split_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION]]])
+=item split_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION [, OPTS]]]])
 
 Splits a string on a fixed delimiter according to the BibTeX rules for
 splitting up lists of names.  With BibTeX, the delimiter is hard-coded
@@ -607,7 +624,23 @@ STRING are considered delimiters if they are at brace-depth zero,
 surrounded by whitespace, and not at the beginning or end of STRING; the
 comparison is case-insensitive.  See L<bt_split_names> for full details
 of how splitting is done (it's I<not> the same as Perl's C<split>
-function).
+function). OPTS is a hash ref of the same binmode and normalization
+arguments as with, e.g. Text::BibTeX::File->open(). split_list calls isplit_list()
+internally but handles UTF-8 conversion and normalization, if requested.
+
+Returns the list of strings resulting from splitting STRING on DELIM.
+
+=item isplit_list (STRING, DELIM [, FILENAME [, LINE [, DESCRIPTION]]])
+
+Splits a string on a fixed delimiter according to the BibTeX rules for
+splitting up lists of names.  With BibTeX, the delimiter is hard-coded
+as C<"and">; here, you can supply any string.  Instances of DELIM in
+STRING are considered delimiters if they are at brace-depth zero,
+surrounded by whitespace, and not at the beginning or end of STRING; the
+comparison is case-insensitive.  See L<bt_split_names> for full details
+of how splitting is done (it's I<not> the same as Perl's C<split>
+function). This function returns bytes. Use Text::BibTeX::split_list to specify
+the same binmode and normalization arguments as with, e.g. Text::BibTeX::File->open()
 
 Returns the list of strings resulting from splitting STRING on DELIM.
 
